==> piwik-2.3.0.txz: usr/local/www/piwik/README.md <==
# Piwik - piwik.org   

## We’re seeking a talented open source Software Engineer!

Are you looking for a new challenge? We are currently seeking a software engineer or software developer who is passionate about data processing, security, privacy, the open source philosophy and usable interface design.

[View Job Description](http://piwik.org/blog/2014/05/piwik-expanding-seeking-talented-software-engineer-new-zealand-poland/) - [Apply online](http://piwik.org/jobs/)

We are grateful if you can share the Job Description with your friends and colleagues. We can help the right candidate relocate to beautiful New Zealand.

## Description

Piwik is the leading Free/Libre open source Web Analytics platform.

Piwik is a full featured PHP MySQL software program that you download and install on your own webserver.
At the end of the five minute installation process you will be given a JavaScript code.
Simply copy and paste this tag on websites you wish to track and access your analytics reports in real time.

Piwik aims to be a Free software alternative to Google Analytics, and is already used on more than 1,000,000 websites.

## Mission Statement

> « To create, as a community, the leading international Free/Libre web analytics platform, providing access to all functionality through open components and open APIs. »

Or in short:
> « Liberate Web Analytics »

## License

Piwik is released under the GPL v3 (or later) license, see [misc/gpl-3.0.txt](misc/gpl-3.0.txt)

## Requirements

  * PHP 5.3.2 or greater
  * MySQL 4.1 or greater, and either MySQLi or PDO library must be enabled
  * Piwik is OS / server independent

See http://piwik.org/docs/requirements/

## Install 

  * Upload piwik to your webserver 
  * Point your browser to the directory
  * Follow the steps
  * Add the given javascript code to your pages
  * (You may also generate fake data to experiment, by enabling the plugin VisitorGenerator)

See http://piwik.org/docs/installation/

If you do not have a server, consider our Piwik Hosting partner: http://piwik.org/hosting/

## Changelog

For the list of all tickets closed in the current and past releases, see http://piwik.org/changelog/

## Participate!

We believe in liberating Web Analytics, providing a free platform for simple and advanced analytics. Piwik was built by dozens of people like you,
and we need your help to make Piwik better… Why not participate in a useful project today?

You will find pointers on how you can participate in Piwik at http://piwik.org/get-involved/

## Contact

http://piwik.org

hello@piwik.org

About us: http://piwik.org/the-piwik-team/

## More information

What makes Piwik unique from the competition:

  * Real time web analytics reports: in Piwik, reports are by default generated in real time. 
    For high traffic websites, you can choose the frequency for reports to be processed.

  * You own your web analytics data: since Piwik is installed on your server, the data is stored in your own database and you can get all the statistics
  using the powerful Piwik Analytics API.

  * Piwik is a Free Software which can easily be configured to respect your visitors privacy.

  * Modern, easy to use User Interface: you can fully customize your dashboard, drag and drop widgets and more.

  * Piwik features are built inside plugins: you can add new features and remove the ones you don’t need. 
    You can build your own web analytics plugins or hire a consultant to have your custom feature built in Piwik

  * Vibrant international Open community of more than 200,000 active users (tracking even more websites!)

  * Advanced Web Analytics capabilities such as Ecommerce Tracking, Goal tracking, Campaign tracking, 
    Custom Variables, Email Reports, Custom Segment Editor, Geo Location, Real time maps, and more!

Documentation and more info on http://piwik.org

## Code Status
The Piwik project uses an ever-expanding comprehensive set of thousands of unit tests and dozens of integration [tests](https://github.com/piwik/piwik/tree/master/tests),
 running on the hosted distributed continuous integration platform Travis-CI.

Build status (master branch) [![Build Status](https://travis-ci.org/piwik/piwik.png?branch=master)](https://travis-ci.org/piwik/piwik) - Screenshot tests Build  [![Build Status](https://travis-ci.org/piwik/piwik-ui-tests.png?branch=master)](https://travis-ci.org/piwik/piwik-ui-tests)

==> piwik-2.6.1.txz: usr/local/www/piwik/README.md <==
# Piwik - piwik.org

## Description

Piwik is the leading Free/Libre open analytics platform.

Piwik is a full featured PHP MySQL software program that you download and install on your own webserver.
At the end of the five minute installation process you will be given a JavaScript code.
Simply copy and paste this tag on websites you wish to track and access your analytics reports in real time.

Piwik aims to be a Free software alternative to Google Analytics, and is already used on more than 1,000,000 websites. Privacy is built-in!

## Mission Statement

> « To create, as a community, the leading international Free/Libre web analytics platform, providing access to all functionality through open components and open APIs. »

Or in short:
> « Liberate Web Analytics »

## License

Piwik is released under the GPL v3 (or later) license, see [misc/gpl-3.0.txt](misc/gpl-3.0.txt)

## Requirements

  * PHP 5.3.2 or greater
  * MySQL 4.1 or greater, and either MySQLi or PDO library must be enabled
  * Piwik is OS / server independent

See http://piwik.org/docs/requirements/

## Install

  * Upload piwik to your webserver
  * Point your browser to the directory
  * Follow the steps
  * Add the given javascript code to your pages
  * (You may also generate fake data to experiment, by enabling the plugin VisitorGenerator)

See http://piwik.org/docs/installation/

If you do not have a server, consider our Piwik Hosting partner: http://piwik.org/hosting/

## Changelog

For the list of all tickets closed in the current and past releases, see http://piwik.org/changelog/. For the list of technical changes in the Piwik platform, see [http://developer.piwik.org/changelog](http://developer.piwik.org/changelog).

## Participate!

We believe in liberating Web Analytics, providing a free platform for simple and advanced analytics. Piwik was built by dozens of people like you,
and we need your help to make Piwik better… Why not participate in a useful project today?

You will find pointers on how you can participate in Piwik at http://piwik.org/get-involved/

## Contact

http://piwik.org

hello@piwik.org

About us: http://piwik.org/the-piwik-team/

## More information

What makes Piwik unique from the competition:

  * Real time web analytics reports: in Piwik, reports are by default generated in real time.
    For high traffic websites, you can choose the frequency for reports to be processed.

  * You own your web analytics data: since Piwik is installed on your server, the data is stored in your own database and you can get all the statistics
  using the powerful Piwik Analytics API.

  * Piwik is a Free Software which can easily be configured to respect your visitors privacy.

  * Modern, easy to use User Interface: you can fully customize your dashboard, drag and drop widgets and more.

  * Piwik features are built inside plugins: you can add new features and remove the ones you don’t need.
    You can build your own web analytics plugins or hire a consultant to have your custom feature built in Piwik

  * Vibrant international Open community of more than 200,000 active users (tracking even more websites!)

  * Advanced Web Analytics capabilities such as Ecommerce Tracking, Goal tracking, Campaign tracking,
    Custom Variables, Email Reports, Custom Segment Editor, Geo Location, Real time maps, and more!

Documentation and more info on http://piwik.org



## We’re seeking a talented Software Engineer

Are you looking for a new challenge? We are currently seeking a software engineer or software developer who is passionate about data processing, security, privacy, the open source and free/libre philosophy and usable interface design.

[View Job Description](http://piwik.org/blog/2014/05/piwik-expanding-seeking-talented-software-engineer-new-zealand-poland/) - [Apply online](http://piwik.org/jobs/)

We are grateful if you can share the Job Description with your friends and colleagues. We can help the right candidate relocate to beautiful New Zealand.


## Code Status
The Piwik project uses an ever-expanding comprehensive set of thousands of unit tests and dozens of integration [tests](https://github.com/piwik/piwik/tree/master/tests),
 running on the hosted distributed continuous integration platform Travis-CI.

Build status (master branch) [![Build Status](https://travis-ci.org/piwik/piwik.png?branch=master)](https://travis-ci.org/piwik/piwik) - Screenshot tests Build  [![Build Status](https://travis-ci.org/piwik/piwik-ui-tests.png?branch=master)](https://travis-ci.org/piwik/piwik-ui-tests)

Code Coverage: [![Coverage Status](https://coveralls.io/repos/piwik/piwik/badge.png?branch=master)](https://coveralls.io/r/piwik/piwik?branch=master)
